import { Button } from '@/components/ui/button';
import { Dialog, DialogContent, DialogTitle, DialogDescription } from '@/components/ui/dialog';
import { useState, useEffect, lazy, Suspense } from 'react';
import premiumBg from '@/assets/premium-bg.jpg';
import OptimizedImage from './OptimizedImage';

// Lazy load heavy components
const LogoEditor = lazy(() => import('./LogoEditor'));
const OptimizedVideo = lazy(() => import('./OptimizedVideo'));

const HeroSection = () => {
  const [showWelcomeDialog, setShowWelcomeDialog] = useState(false);
  const [logoFlashing, setLogoFlashing] = useState(false);

  useEffect(() => {
    // Show dialog after devil emoji animation (reduced to 1.2 seconds)
    const timer = setTimeout(() => {
      setShowWelcomeDialog(true);
    }, 1200);

    return () => clearTimeout(timer);
  }, []);


  const handleGetTodaysPick = () => {
    console.log('Hero CTA clicked - looking for purchase section');
    const purchaseElement = document.getElementById('purchase');
    console.log('Purchase element found:', purchaseElement);
    if (purchaseElement) {
      purchaseElement.scrollIntoView({ behavior: 'smooth' });
      console.log('Scrolling to purchase section');
    } else {
      console.error('Purchase section not found!');
    }
  };

  const handleAccess = () => {
    setShowWelcomeDialog(false);
    // Start logo flashing for 30 seconds after ACCESS is clicked
    setLogoFlashing(true);
    setTimeout(() => {
      setLogoFlashing(false);
    }, 30000);
    // Scroll to top of page (hero section)
    window.scrollTo({ top: 0, behavior: 'smooth' });
  };

  return (
    <>
      <section className="relative min-h-screen flex items-center justify-center overflow-hidden">
      {/* Animated Purple Devil Emoji Overlay */}
      <div className="absolute inset-0 z-50 flex items-start justify-center pt-20 bg-max-dark animate-devil-entrance pointer-events-none">
        <div className="relative">
          {/* Glow rings */}
          <div className="absolute inset-0 animate-pulse">
            <div className="w-80 h-80 border-4 border-max-purple/30 rounded-full animate-spin absolute top-1/2 left-1/2 transform -translate-x-1/2 -translate-y-1/2"></div>
            <div className="w-96 h-96 border-2 border-max-purple/20 rounded-full animate-spin absolute top-1/2 left-1/2 transform -translate-x-1/2 -translate-y-1/2" style={{ animationDirection: 'reverse', animationDuration: '3s' }}></div>
          </div>
          {/* Main devil emoji with high-tech effects */}
          <div 
            className="text-[20rem] animate-devil-laugh relative z-10" 
            style={{ 
              filter: 'hue-rotate(280deg) brightness(1.2) contrast(1.5)',
              textShadow: '0 0 30px hsl(280 95% 60%), 0 0 60px hsl(280 95% 60%), 0 0 90px hsl(280 95% 60%)',
              background: 'linear-gradient(45deg, hsl(280 95% 60%), hsl(270 70% 45%))',
              WebkitBackgroundClip: 'text',
              WebkitTextFillColor: 'transparent'
            }}
          >
            😈
          </div>
          {/* Scan lines effect */}
          <div className="absolute inset-0 pointer-events-none overflow-hidden">
            <div className="absolute inset-0 bg-gradient-to-b from-transparent via-max-purple/20 to-transparent h-4 animate-scan-line"></div>
          </div>
        </div>
      </div>

      {/* Background with overlay */}
      <div 
        className="absolute inset-0 bg-cover bg-center bg-no-repeat"
        style={{ backgroundImage: `url(${premiumBg})` }}
      >
        <div className="absolute inset-0 bg-max-dark/80"></div>
      </div>
      
      {/* Content */}
      <div className="relative z-10 max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-12">
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-8 lg:gap-12 items-center">
          
          {/* Left: Hero Text */}
          <div className="text-center lg:text-left">
            
            {/* Mobile Logo - Only visible on mobile */}
            <div className={logoFlashing ? 'animate-logo-flash-30s' : ''}>
              <Suspense fallback={
                <div className="w-24 h-24 bg-card/20 rounded-lg animate-pulse" />
              }>
                <LogoEditor 
                  imageUrl="/lovable-uploads/527f129f-fbc6-4ea1-a61d-b05b2843132d.png"
                />
              </Suspense>
            </div>
            
            <h1 className="max-hero-text mb-4 md:mb-6 font-display">
              <span className="text-foreground font-black">CHAMBA'S</span>
              <br />
              <span className="bg-max-gradient bg-clip-text text-transparent font-black text-6xl md:text-8xl lg:text-9xl">MAX PLAY</span>
              <br />
              <span className="text-foreground font-black">OF THE DAY</span>
            </h1>
            
            <div className="max-subhero-text text-foreground/90 mb-6 md:mb-8 leading-tight">
              <span className="text-max-green font-display font-bold">My top-selling, high-ticket picks that I personally hammer — backed by 90%+ confidence.</span>
            </div>

            {/* CTA Button */}
            <div className="flex justify-center lg:justify-start mb-8">
              <div className="relative">
                {/* White light behind button */}
                <div className="absolute -inset-4 bg-white/30 rounded-full blur-xl animate-pulse"></div>
                <div className="absolute -inset-2 bg-white/20 rounded-2xl blur-lg"></div>
                
                <Button 
                  variant="max" 
                  size="xl"
                  onClick={handleGetTodaysPick}
                  onTouchEnd={handleGetTodaysPick}
                  className="group relative overflow-hidden touch-manipulation"
                  role="button"
                  tabIndex={0}
                >
                  <span className="relative z-10">GET MAX PLAY</span>
                  <div className="absolute inset-0 bg-max-gold opacity-0 group-hover:opacity-20 transition-opacity"></div>
                </Button>
              </div>
            </div>

            {/* Enhanced Stats with Bubbles */}
            <div className="space-y-6">

              {/* Stats Grid with Bubbles */}
              <div className="grid grid-cols-3 gap-3 md:gap-4">
                {/* Consecutive Wins */}
                <div className="relative group">
                  <div className="absolute inset-0 bg-max-purple/20 rounded-2xl blur-sm group-hover:blur-md transition-all"></div>
                  <div className="relative bg-card/50 backdrop-blur-sm border border-max-purple/20 rounded-2xl p-4 text-center hover:border-max-purple/40 transition-all">
                    <div className="text-center">
                      <div className="text-2xl mb-1">🏆</div>
                      <div className="text-2xl md:text-3xl font-black text-max-purple mb-1">16</div>
                    </div>
                    <div className="text-xs text-muted-foreground font-bold leading-tight">Consecutive<br />Wins</div>
                  </div>
                </div>

                {/* Win Rate */}
                <div className="relative group">
                  <div className="absolute inset-0 bg-max-green/20 rounded-2xl blur-sm group-hover:blur-md transition-all"></div>
                  <div className="relative bg-card/50 backdrop-blur-sm border border-max-green/20 rounded-2xl p-4 text-center hover:border-max-green/40 transition-all">
                    <div className="text-center">
                      <div className="text-2xl mb-1">🎯</div>
                      <div className="text-2xl md:text-3xl font-black text-max-green mb-1">73%</div>
                    </div>
                    <div className="text-xs text-muted-foreground font-bold leading-tight">Win<br />Rate</div>
                  </div>
                </div>

                {/* Member Wins */}
                <div className="relative group">
                  <div className="absolute inset-0 bg-max-purple/20 rounded-2xl blur-sm group-hover:blur-md transition-all"></div>
                  <div className="relative bg-card/50 backdrop-blur-sm border border-max-purple/20 rounded-2xl p-4 text-center hover:border-max-purple/40 transition-all">
                    <div className="text-center">
                      <div className="text-2xl mb-1">💸</div>
                      <div className="text-2xl md:text-3xl font-black text-max-purple mb-1">$20M+</div>
                    </div>
                    <div className="text-xs text-muted-foreground font-bold leading-tight">Member<br />Wins</div>
                  </div>
                </div>
              </div>
            </div>
          </div>

          {/* Right: Video */}
          <div className="flex flex-col items-center space-y-6">
            <div className="relative">
              <div className="absolute -inset-1 bg-max-gradient rounded-3xl blur opacity-75 animate-max-pulse"></div>
              <div className="relative bg-card/10 backdrop-blur-sm rounded-2xl overflow-hidden shadow-max-premium">
                <Suspense fallback={
                  <div className="max-w-2xl aspect-[9/16] rounded-2xl bg-card/20 flex items-center justify-center">
                    <OptimizedImage
                      src="/lovable-uploads/527f129f-fbc6-4ea1-a61d-b05b2843132d.png"
                      alt="Video thumbnail"
                      className="w-full h-full object-cover rounded-2xl"
                      priority={true}
                    />
                  </div>
                }>
                  <OptimizedVideo
                    src="https://content.apisystem.tech/hls/medias/piN7ZfaMrBWL7y1NYrva/media/transcoded_videos/cts-80b74c27a404c8e8_,360,480,720,1080,1440,p.mp4.urlset/master.m3u8"
                    className="max-w-2xl aspect-[9/16] rounded-2xl touch-manipulation"
                    poster="/lovable-uploads/527f129f-fbc6-4ea1-a61d-b05b2843132d.png"
                    videoId="hero-video"
                  />
                </Suspense>
              </div>
              <div className="absolute -bottom-4 -right-4 bg-max-success-gradient text-max-dark px-4 py-2 rounded-xl font-black text-sm md:text-base">
                🏆 #1 RATED
              </div>
            </div>
          </div>
        </div>

      </div>
      </section>

      {/* Welcome Dialog */}
      <Dialog open={showWelcomeDialog} onOpenChange={setShowWelcomeDialog}>
        <DialogContent className="max-w-md mx-auto bg-max-dark border-2 border-max-purple/50 text-center p-8">
          <DialogTitle className="sr-only">Welcome to Max Play</DialogTitle>
          <DialogDescription className="sr-only">Join our winning streak with 73-27 performance</DialogDescription>
          <div className="space-y-6">
            <div className="text-2xl font-black text-foreground">
              Max Play is on a{' '}
              <span className="text-max-green">73–27</span>{' '}
              run.
            </div>
            <div className="text-xl text-muted-foreground">
              You in?
            </div>
            <Button 
              variant="max" 
              size="lg" 
              onClick={handleAccess}
              className="w-full font-black text-lg bg-gradient-to-r from-max-green to-max-purple hover:from-max-green/80 hover:to-max-purple/80"
            >
              ACCESS
            </Button>
          </div>
        </DialogContent>
      </Dialog>
    </>
  );
};

export default HeroSection;